#
# spec file for package sqlmap
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sqlmap
Version:        1.9
Release:        1.3
Summary:        Automatic SQL injection and database takeover tool
License:        GPL-2.0-or-later
URL:            https://sqlmap.org/
Source:         https://github.com/sqlmapproject/sqlmap/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         fix_shebang.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python3
BuildArch:      noarch

%description

sqlmap is an open source penetration testing tool that automates the process of
detecting and exploiting SQL injection flaws and taking over of database
servers. It comes with a powerful detection engine, many niche features for the
ultimate penetration tester, and a broad range of switches including database
fingerprinting, over data fetching from the database, accessing the underlying
file system, and executing commands on the operating system via out-of-band
connections.

%prep
%autosetup -p1 -n sqlmap-%{version}
find extra lib plugins tamper thirdparty -iname "*.py" -exec sed -i '1{/^#!/ d}' {} \;
find extra lib plugins tamper thirdparty -iname "*.pl" -exec sed -i '1{/^#!/ d}' {} \;
mv extra/icmpsh/icmpsh-m.c extra/icmpsh/icmpsh-m.c.txt
mv extra/icmpsh/icmpsh-s.c extra/icmpsh/icmpsh-s.c.txt
mv extra/runcmd/src/runcmd/runcmd.cpp extra/runcmd/src/runcmd/runcmd.cpp.txt
mv extra/runcmd/src/runcmd/stdafx.cpp extra/runcmd/src/runcmd/stdafx.cpp.txt
mv extra/runcmd/src/runcmd/stdafx.h extra/runcmd/src/runcmd/stdafx.h.txt
chmod ugo-x extra/shutils/duplicates.py
chmod ugo-x thirdparty/identywaf/identYwaf.py
chmod ugo-x plugins/dbms/clickhouse/*.py

%build

%install
mkdir -p %{buildroot}%{_datadir}/sqlmap
cp -a * %{buildroot}%{_datadir}/sqlmap

%python_expand %fdupes %{buildroot}%{_datadir}/sqlmap

%post
ln -s -f  %{_datadir}/sqlmap/sqlmap.py %{_bindir}
ln -s -f  %{_datadir}/sqlmap/sqlmapapi.py %{_bindir}

%postun
case "$1" in
  0) # last one out put out the lights
    rm -f %{_bindir}/sqlmap.py
    rm -f %{_bindir}/sqlmapapi.py
  ;;
esac

%files
%{_datadir}/sqlmap

%license %{_datadir}/sqlmap/LICENSE
%doc %{_datadir}/sqlmap/README.md

%changelog
* Sat Jan  4 2025 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.9:
  * Implements --disable-hashing (#5827)
  * fixed #5828 Clickhouse - Unable to retrieve tables
  * update of checksums
* Wed Nov 27 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.8.11:
  * fixed #5772, #5761 unhandled exception
  * fixed #5763 Can not perform sql blind injection again latest dvwa
  * fixed #5798 Some bugs with common tables and columns check
  * fixed #5767 direct connection to oracle database not working
  * update translations
* Mon Sep  2 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.8.8:
  * fixed #5727 SQLAlchemy connection issue
  * fixed #5725 Arbitrary Injection Point Not Working
  * implements #5728 More error-based payloads
  * fixed #5738 probing web services on non-standard ports
  * fixed #5731 python 3.13 compatibility
  * fixed #4613 Single column enumeration (-C) broken for Firebird backend
  * fixed #5755, #5759 Unhandled exception
* Sat May 25 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.8.5:
  * Patch related to the #5700 (Send raw binary data to postprocess function)
- update to 1.8.4:
  * Removing some obsolete code
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 1.8.3:
  * Adding switch '--unsafe-naming'
  * Fixes #5619
  * Fixes #5590
  * Add Patch related to empty multiform-data field value
  * Fix Python 3.12 warnings
* Fri Jan  5 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.8:
  * H2 queries to get data use wrong order for LIMIT and OFFSET (#5580)
  * Cleaning some mess with limitQuery
  * fix issue #5571, #5229, #5581, #5585
  * update documentation and copyright year
* Fri Dec  1 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.12:
  * Fixes #5567, #5566, #5574, #5576
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.11:
  * Fixes: #5539, #5549, #5560, #5565
* Tue Oct 10 2023 Paolo Stivanin <info@paolostivanin.com>
- update to 1.7.10:
  * Fixes: #5536, #5502, #5521
* Thu Sep 14 2023 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.7.9:
  * Removing support for lol FORKZ
  * Fixes #5476
  * Fixes #5481
  * Fixes #5479
  * Fixes #5477
  * Potential fix for #5485
  * Patch for #5485
  * Fixes #5493
  * Fixes #5492
  * Fixes #5483
  * Add SQLite AND boolean-based blind payload (#5501)
  * Fixes #5510
  * Implements option --union-values (#5508)
* Wed Jul 19 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.7:
  * Fixes #5428
  * Fixes #5431
  * Fixes #5434
  * Fixes #5444
  * Fixes #5445
  * Implements #5452
* Fri Jun 16 2023 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.7.6:
  * Bugfixes: #5428, #5409, #5381, #5358
* Mon Feb 13 2023 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.7.2:
  * Implements tamper script if2case
  * Bugfixes
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 1.6.12:
  * Better handling of CookieJar Runtime Exception
  * Fixes #5216
  * Fixes #5220
  * Fixes #5233
  * Fixes #5232
  * Fixes #5240
  * Fixes #5242
  * Fixes #5252
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 1.6.11:
  * Fixes #5190
  * Fixes #5191
  * Fixes #5192
  * Implement --csrf-data
  * Fix --cookie-del
  * Fixes #5216
* Mon Oct 10 2022 Dirk Müller <dmueller@suse.com>
- update to 1.6.10:
  * Fixes #5187
  * Fixes #5182
  * Fixes #5170
  * Fixes #5165
  * Fixes #5162
  * Fixes #5154
  * Fixes #5152
  * Fixes #5147
* Wed Aug  3 2022 Dirk Müller <dmueller@suse.com>
- update to 1.6.7:
  * https://github.com/sqlmapproject/sqlmap/compare/1.5.7...1.6.7
* Tue Aug 31 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update fix_shebang.patch to switch Python scripts to calling
  /usr/bin/python3.
- Add Requires on python3 for full interpreter.
* Thu Jul 15 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.5.7:
  * Fixed #4728 (https://github.com/sqlmapproject/sqlmap/issues/4728)
  * Fixed #4664 (https://github.com/sqlmapproject/sqlmap/issues/4664)
  * Fixed #4625 (https://github.com/sqlmapproject/sqlmap/issues/4625)
  * Speedup of caching for char encoding (non-Unicode chars in page)
  * Fixing HTTP chunking for Python2.6
* Thu Jul  1 2021 Paolo Perego <paolo.perego@suse.com>
- First import from upstream
